@@ -1,11 +1,5 @@
 from minet.__version__ import __version__
 
-from minet.crawl import (
-    Crawler,
-    CrawlJob,
-    Spider,
-    BeautifulSoupSpider,
-    DefinitionSpider
-)
+from minet.crawl import Crawler, CrawlJob, Spider, BeautifulSoupSpider, DefinitionSpider
 from minet.fetch import multithreaded_fetch, multithreaded_resolve
 from minet.scrape import Scraper
