@@ -18,8 +18,9 @@ class CrowdTangleInvalidTokenError(CrowdTangleError):
 
 
 class CrowdTangleInvalidRequestError(CrowdTangleError):
-    def __init__(self, message=None, status=None, code=None):
+    def __init__(self, message=None, url=None, status=None, code=None):
         super().__init__(message)
+        self.url = url
         self.code = code
         self.status = status
 
@@ -27,7 +28,24 @@ class CrowdTangleInvalidRequestError(CrowdTangleError):
         if self.status is None:
             return super().__str__()
 
-        return super().__str__() + ', Code: %i, Status: %i' % (self.code, self.status)
+        return super().__str__() + ", Url: %s, Code: %s, Status: %s" % (
+            self.url,
+            self.code,
+            self.status,
+        )
+
+
+class CrowdTangleServerError(CrowdTangleError):
+    def __init__(self, url=None, status=None):
+        super().__init__()
+        self.url = url
+        self.status = status
+
+    def __str__(self):
+        if self.status is None:
+            return super().__str__()
+
+        return super().__str__() + "%s Status: %s" % (self.url, self.status)
 
 
 class CrowdTangleMissingStartDateError(CrowdTangleError):
