@@ -7,7 +7,7 @@
 
 
 def should_spoof_ua_when_resolving(domain):
-    if domain == 't.co':
+    if domain == "t.co":
         return False
 
     return True
