@@ -21,8 +21,20 @@ class YouTubeInvalidAPICall(YouTubeError):
         self.data = data
 
     def __str__(self):
-        return super().__str__() + ', Url: %s, Status: %i, Data: %s' % (self.url, self.status, self.data)
+        return super().__str__() + ", Url: %s, Status: %i, Data: %s" % (
+            self.url,
+            self.status,
+            self.data,
+        )
 
 
 class YouTubeInvalidVideoId(YouTubeError):
     pass
+
+
+class YouTubeDisabledComments(YouTubeError):
+    pass
+
+
+class YouTubeVideoNotFound(YouTubeError):
+    pass
